@@ -123,7 +123,7 @@ class PyPdfFileReader(PdfFileReader):
         startxref_addr = last1k.rfind(b_('startxref'))+len(b_('startxref\n'))
         filesize_addr = last1k.rfind(b_('%%EOF'))+len(b_('%%EOF\n'))
 
-        old_size = int(last1k[filesize_addr:].split()[0]) #TO-DO: split() looks unnecessary here
+        old_size = int(last1k[filesize_addr:].split()[0])
         offset = len(read_buf) - old_size + 1 
         startxref = int(last1k[startxref_addr:].split()[0]) + offset
 
@@ -179,7 +179,7 @@ class PyPdfFileReader(PdfFileReader):
 
     def extractEmbeddedFiles(self,verbose = True):
         
-        root_obj = self._trailer['/Root']
+        root_obj = (self.trailer if legacy else self._trailer)['/Root']
         file_dict = root_obj['/Names']['/EmbeddedFiles']['/Names']
         
         pyname = root_obj['/PyFile']
@@ -262,16 +262,19 @@ class PyPdfFileWriter(PdfFileWriter):
         self._rootObject[NameObject("/PageMode")] = NameObject("/UseAttachments")
 
     def setPyFile(self,fname):
-        #TO-DO: use doc info instead of root object
         self._rootObject[NameObject('/PyFile')] = createStringObject(fname)
 
     def setPyPDFVersion(self,version):
-        #TO-DO: use doc info instead of root object
+        
+        self.pypdf_version = version
+
+        major_str, minor_str = version.split('.')[:2]
+        self.major_pypdf_version = int(major_str)
+        self.minor_pypdf_version = int(minor_str)
         self._rootObject[NameObject('/PyPDFVersion')] = createStringObject(version)
 
-    def setNewlineChar(self,newline_char):
-        #TO-DO: use doc info instead of root object
-        self._rootObject[NameObject('/PyPDFNewlineChar')] = createStringObject(newline_char)
+##    def setNewlineChar(self,newline_char):
+##        self._rootObject[NameObject('/PyPDFNewlineChar')] = createStringObject(newline_char)
 
     def write(self,fstream):
         """
@@ -429,10 +432,10 @@ class PyPdfFileWriter(PdfFileWriter):
         trailer.writeToStream(self._stream, None)
 
         eof  = '\nstartxref\n{:d}\n%%EOF'.format(xref_location)
-        eof += '\n{:000010d}\nPyPDF\n"""\n'
+        eof += '\n{:000010d} LF\nPyPDF-' + self.pypdf_version
+        eof += '\n"""\n'
         eof = b_(eof.format(self._stream.tell()+len(eof)))
         self._stream.write(eof)
-
             
         self._stream.seek(0)
 
